@@ -10,7 +10,7 @@ from datetime import datetime
 import pandas as pd
 from loguru import logger
 import mns_common.api.ths.concept.web.ths_company_info_web as ths_company_info_web
-import mns_common.api.em.east_money_stock_v2_api as east_money_stock_v2_api
+import mns_common.component.em.em_stock_info_api as em_stock_info_api
 import mns_common.component.common_service_fun_api as common_service_fun_api
 import mns_common.component.concept.ths_concept_common_service_api as ths_concept_common_service_api
 from mns_common.db.MongodbUtil import MongodbUtil
@@ -37,29 +37,96 @@ result = []
 # 计算实际流通比例
 def calculate_circulation_ratio(symbol):
     query = {"symbol": symbol}
-    stock_gdfx_free_top_10 = mongodb_util.descend_query(query, 'stock_gdfx_free_top_10', "period", 10)
-    if stock_gdfx_free_top_10.shape[0] == 0:
+    stock_gdfx_free_top_1 = mongodb_util.descend_query(query, 'stock_gdfx_free_top_10', "period", 1)
+    if stock_gdfx_free_top_1.shape[0] == 0:
         mv_circulation_ratio = 1
     else:
+        period_time = list(stock_gdfx_free_top_1['period'])[0]
+
+        query_free = {'symbol': symbol, 'period': period_time}
+        stock_gdfx_free_top_10 = mongodb_util.find_query_data('stock_gdfx_free_top_10', query_free)
+
+        stock_gdfx_free_top_10['shares_number_str'] = stock_gdfx_free_top_10['shares_number'].astype(str)
+
+        stock_gdfx_free_top_10['id_key'] = stock_gdfx_free_top_10['symbol'] + '_' + stock_gdfx_free_top_10[
+            'period'] + '_' + stock_gdfx_free_top_10.shares_number_str
+
+        stock_gdfx_free_top_10.drop_duplicates('id_key', keep='last', inplace=True)
+
         # 排除香港结算公司 大于5%减持不用发公告  香港中央结算    HKSCC
         stock_gdfx_free_top_10['is_hk'] = stock_gdfx_free_top_10['shareholder_name'].apply(
             lambda shareholder_name: "HK" if shareholder_name.startswith('香港中央结算') or shareholder_name.startswith(
                 'HKSCC') else "A")
 
-        # 持股大于5%      # 排除香港结算公司 大于5%减持不用发公告  香港中央结算    HKSCC
-        stock_gdfx_free_top_10 = stock_gdfx_free_top_10.loc[
+        # 持股大于5% 减持需要发公告
+        # 排除香港结算公司不发公共 小于5%减持不用发公告
+        # 香港中央结算    HKSCC
+        stock_free_top_greater_than_5 = stock_gdfx_free_top_10.loc[
             (stock_gdfx_free_top_10['circulation_ratio'] >= 5) & (stock_gdfx_free_top_10['is_hk'] == 'A')]
 
-        circulation_ratio = sum(stock_gdfx_free_top_10['circulation_ratio'])
+        stock_free_qfii = stock_gdfx_free_top_10.loc[stock_gdfx_free_top_10['shareholder_nature'] == 'QFII']
+
+        share_holder_sync_day = list(stock_gdfx_free_top_10['create_day'])[0]
+
+        # qfii 数量
+        qfii_number = stock_free_qfii.shape[0]
+        # qfii 类型
+        qfii_type = set_qfii_type(qfii_number, stock_free_qfii.copy())
+
+        circulation_ratio = sum(stock_free_top_greater_than_5['circulation_ratio'])
         mv_circulation_ratio = round((100 - circulation_ratio) / 100, 2)
         # 防止错误数据
         if mv_circulation_ratio < 0:
             mv_circulation_ratio = 1
-    return mv_circulation_ratio
+
+    result_dict = {
+        'mv_circulation_ratio': mv_circulation_ratio,
+        'qfii_type': qfii_type,
+        'qfii_number': qfii_number,
+        'share_holder_sync_day': share_holder_sync_day
+
+    }
+    return result_dict
+
+
+def set_qfii_type(qfii_number, stock_free_qfii):
+    if qfii_number > 0:
+        stock_free_qfii['new_change'] = stock_free_qfii['change']
+        stock_free_qfii.loc[stock_free_qfii['change_ratio'] == 0, 'new_change'] = 0
+        stock_free_qfii.loc[stock_free_qfii['change'] == '新进', 'new_change'] = \
+            stock_free_qfii['shares_number']
+        stock_free_qfii['new_change'] = stock_free_qfii['new_change'].astype(float)
+
+        stock_free_qfii_new_in = stock_free_qfii.loc[stock_free_qfii['change'] == '新进']
+        if data_frame_util.is_not_empty(stock_free_qfii_new_in):
+            qfii_type = 1
+            return qfii_type
+
+        stock_free_qfii_add = stock_free_qfii.loc[
+            (~stock_free_qfii['change'].isin(['不变', '新进'])) & (stock_free_qfii['new_change'] > 0)]
+
+        if data_frame_util.is_not_empty(stock_free_qfii_add):
+            qfii_type = 2
+            return qfii_type
+
+        stock_free_qfii_not_change = stock_free_qfii.loc[stock_free_qfii['change'] == '不变']
+
+        if data_frame_util.is_not_empty(stock_free_qfii_not_change):
+            qfii_type = 3
+            return qfii_type
+
+        stock_free_qfii_reduce = stock_free_qfii.loc[
+            (~stock_free_qfii['change'].isin(['不变', '新进'])) & (stock_free_qfii['new_change'] < 0)]
+
+        if data_frame_util.is_not_empty(stock_free_qfii_reduce):
+            qfii_type = 4
+            return qfii_type
+    else:
+        return 0
 
 
 def get_east_money_stock_info():
-    all_real_time_quotes = east_money_stock_v2_api.get_all_real_time_quotes()
+    all_real_time_quotes = em_stock_info_api.get_a_stock_info()
     all_real_time_quotes = all_real_time_quotes[['symbol',
                                                  'name',
                                                  "now_price",
@@ -201,7 +268,13 @@ def single_thread_sync_company_info(east_money_stock_info,
             company_info_type['total_mv_sp'] = company_one.total_mv_sp
             company_info_type['flow_mv_level'] = company_one.flow_mv_level
             company_info_type['classification'] = company_one.classification
-            company_info_type['mv_circulation_ratio'] = calculate_circulation_ratio(company_one.symbol)
+
+            result_dict = calculate_circulation_ratio(company_one.symbol)
+            company_info_type['mv_circulation_ratio'] = result_dict['mv_circulation_ratio']
+            company_info_type['qfii_type'] = result_dict['qfii_type']
+            company_info_type['qfii_number'] = result_dict['qfii_number']
+            company_info_type['share_holder_sync_day'] = result_dict['share_holder_sync_day']
+
             # 获取同花顺最新概念
             company_info_type = ths_concept_common_service_api.set_ths_concept(company_one.symbol, company_info_type)
             now_date = datetime.now()
@@ -395,19 +468,25 @@ def save_sw_data(company_info_type):
 def get_recent_year_income(symbol, company_info_type, exist_company_df):
     now_date = datetime.now()
     hour = now_date.hour
-    if hour <= 15:
-        exist_company_one_df = exist_company_df.loc[exist_company_df['_id'] == symbol]
-        if data_frame_util.is_not_empty(exist_company_one_df):
-            company_info_type['operate_profit'] = list(exist_company_one_df['operate_profit'])[0]
-            company_info_type['total_operate_income'] = list(exist_company_one_df['total_operate_income'])[0]
-        else:
-            company_info_type['operate_profit'] = 0
-            company_info_type['total_operate_income'] = 0
-        return company_info_type
+    # if hour <= 15:
+    #     exist_company_one_df = exist_company_df.loc[exist_company_df['_id'] == symbol]
+    #     if data_frame_util.is_not_empty(exist_company_one_df):
+    #         company_info_type['operate_profit'] = list(exist_company_one_df['operate_profit'])[0]
+    #         company_info_type['total_operate_income'] = list(exist_company_one_df['total_operate_income'])[0]
+    #         if 'operate_date_name' in exist_company_one_df:
+    #             company_info_type['operate_date_name'] = list(exist_company_one_df['total_operate_income'])[0]
+    #         else:
+    #             company_info_type['operate_date_name'] = '暂无年报'
+    #     else:
+    #         company_info_type['operate_profit'] = 0
+    #         company_info_type['total_operate_income'] = 0
+    #         company_info_type['operate_date_name'] = '暂无年报'
+    #     return company_info_type
     query = {'symbol': symbol, "REPORT_TYPE": "年报"}
     em_stock_profit = mongodb_util.descend_query(query, db_name_constant.EM_STOCK_PROFIT, 'REPORT_DATE', 1)
     if data_frame_util.is_not_empty(em_stock_profit):
         company_info_type['operate_profit'] = list(em_stock_profit['OPERATE_PROFIT'])[0]
+        company_info_type['operate_date_name'] = list(em_stock_profit['REPORT_DATE_NAME'])[0]
         total_operate_income = list(em_stock_profit['TOTAL_OPERATE_INCOME'])[0]
         # 金融机构大多收入计入在这个字段中
         if total_operate_income == 0:
@@ -417,6 +496,7 @@ def get_recent_year_income(symbol, company_info_type, exist_company_df):
     else:
         company_info_type['operate_profit'] = 0
         company_info_type['total_operate_income'] = 0
+        company_info_type['operate_date_name'] = '暂无年报'
     company_info_type['operate_profit'] = round(
         company_info_type['operate_profit'] / common_service_fun_api.HUNDRED_MILLION, 2)
     company_info_type['total_operate_income'] = round(
@@ -438,4 +518,5 @@ if __name__ == '__main__':
     # un_report_company_info = mongodb_util.find_query_data(db_name_constant.COMPANY_INFO, query)
     # symbol_list = list(un_report_company_info['symbol'])
     sync_company_base_info(None)
-    # group_by_industry()
+    sync_company_base_info(['688211', '601600', '920821', '920579', '688371', '920367'])
+
