@@ -2,7 +2,7 @@ import sys
 import os
 
 file_path = os.path.abspath(__file__)
-end = file_path.index('mns') + 16
+end = file_path.index('mns') + 17
 project_path = file_path[0:end]
 sys.path.append(project_path)
 import mns_common.api.ths.company.ths_company_info_api as ths_company_info_api
@@ -27,11 +27,8 @@ def sync_company_hold_info(symbol):
         now_date = datetime.now()
         sync_str_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
         if data_frame_util.is_not_empty(company_hold_info_df):
-            query = {'symbol': symbol}
-            result = mongodb_util.remove_data(query, db_name_constant.COMPANY_HOLDING_INFO)
-            if result.acknowledged:
-                company_hold_info_df['sync_str_date'] = sync_str_date
-                mongodb_util.insert_mongo(company_hold_info_df, db_name_constant.COMPANY_HOLDING_INFO)
+            company_hold_info_df['sync_str_date'] = sync_str_date
+            mongodb_util.insert_mongo(company_hold_info_df, db_name_constant.COMPANY_HOLDING_INFO)
     except BaseException as e:
         logger.error("同步公司控股子公司信息:{},{}", symbol, e)
 
