@@ -7,7 +7,7 @@ project_path = file_path[0:end]
 sys.path.append(project_path)
 from mns_common.db.MongodbUtil import MongodbUtil
 import pandas as pd
-import mns_common.utils.data_frame_util as data_frame_util
+import mns_common.api.ths.concept.web.ths_concept_index_web as ths_concept_index_web
 import time
 from loguru import logger
 import mns_common.component.company.company_common_service_api as company_common_service_api
@@ -107,10 +107,7 @@ def update_null_name():
         exist_url = concept_one.url
 
         if name == '':
-            concept_name_df = ths_concept_index_app.get_new_concept_from_app_search(concept_code)
-            if data_frame_util.is_empty(concept_name_df):
-                continue
-            concept_name = list(concept_name_df['concept_name'])[0]
+            concept_name = ths_concept_index_web.get_concept_name(concept_code)
             query_concept = {"symbol": concept_code}
             new_values = {'$set': {"name": concept_name}}
             mongodb_util.update_one_query(query_concept, new_values, 'ths_concept_list')
@@ -131,7 +128,7 @@ def update_null_name():
 
 
 if __name__ == '__main__':
-    update_one_concept_relevance_industry(886095)
+    # update_one_concept_relevance_industry(886095)
     update_null_name()
     logger.info("开始")
     update_ths_concept_info()
