@@ -9,7 +9,7 @@ import mns_common.component.concept.ths_concept_common_service_api as ths_concep
 import mns_common.component.common_service_fun_api as common_service_fun_api
 import mns_common.api.ths.concept.app.ths_concept_detail_app as ths_concept_detail_app
 import mns_common.api.ths.wen_cai.ths_wen_cai_api as ths_wen_cai_api
-import mns_common.api.em.east_money_stock_api as east_money_stock_api
+import mns_common.component.em.em_stock_info_api as em_stock_info_api
 import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
 import mns_common.api.ths.concept.web.ths_concept_detail_web as ths_concept_detail_web
 import math
@@ -24,7 +24,7 @@ import mns_common.constant.redis_msg_constant as redis_msg_constant
 
 
 def get_ths_concept_detail(concept_code, concept_name):
-    real_time_quotes_all_stocks = east_money_stock_api.get_real_time_quotes_all_stocks()
+    real_time_quotes_all_stocks = em_stock_info_api.get_a_stock_info()
     # 1  通过入选理获取概念组成股票详情
     ths_concept_detail_by_explain = get_ths_concept_detail_by_explain(concept_code, real_time_quotes_all_stocks)
     # 2 app 分享链接获取概念组成详情
