@@ -16,10 +16,11 @@ import mns_common.component.common_service_fun_api as common_service_fun_api
 import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
 import mns_common.api.ths.zt.ths_stock_zt_pool_v2_api as ths_stock_zt_pool_v2_api
 import mns_common.component.zt.zt_common_service_api as zt_common_service_api
-import mns_common.api.em.east_money_stock_api as east_money_stock_api
+import mns_common.component.em.em_real_time_quotes_api as em_real_time_quotes_api
 from datetime import datetime
 import mns_common.api.ths.company.ths_company_info_api as ths_company_info_api
 import mns_common.component.cookie.cookie_info_service as cookie_info_service
+import mns_common.api.ths.zt.ths_stock_zt_pool_api as ths_stock_zt_pool_api
 
 '''
 东方财富涨停池
@@ -44,7 +45,7 @@ ZT_FIELD = ['_id', 'symbol', 'name', 'now_price', 'chg', 'first_closure_time',
             'list_date',
             'exchange', 'flow_mv', 'total_mv',
             'classification', 'flow_mv_sp', 'total_mv_sp', 'flow_mv_level',
-            'amount_level', 'new_stock', 'list_date_01', 'index', 'str_day', 'main_line']
+            'amount_level', 'new_stock', 'list_date_01', 'index', 'str_day', 'main_line', 'sub_main_line']
 
 
 def save_zt_info(str_day):
@@ -55,16 +56,18 @@ def save_zt_info(str_day):
         date_handle_util.no_slash_date(str_day))
 
     # fix 涨停池没有的股票
-    stock_em_zt_pool_df_data = sync_miss_zt_data(stock_em_zt_pool_df_data, str_day)
+    stock_em_zt_pool_df_data = sync_miss_zt_data(stock_em_zt_pool_df_data.copy(), str_day)
 
-    stock_em_zt_pool_df_data = common_service_fun_api.total_mv_classification(stock_em_zt_pool_df_data)
+    stock_em_zt_pool_df_data = common_service_fun_api.total_mv_classification(stock_em_zt_pool_df_data.copy())
 
-    stock_em_zt_pool_df_data = common_service_fun_api.classify_symbol(stock_em_zt_pool_df_data)
+    stock_em_zt_pool_df_data = common_service_fun_api.classify_symbol(stock_em_zt_pool_df_data.copy())
 
-    stock_em_zt_pool_df_data = common_service_fun_api.symbol_amount_simple(stock_em_zt_pool_df_data)
-
-    stock_em_zt_pool_df_data = company_common_service_api.amendment_industry(stock_em_zt_pool_df_data)
+    stock_em_zt_pool_df_data = common_service_fun_api.symbol_amount_simple(stock_em_zt_pool_df_data.copy())
 
+    stock_em_zt_pool_df_data = company_common_service_api.amendment_industry(stock_em_zt_pool_df_data.copy())
+    # 主线标记 复盘用
+    stock_em_zt_pool_df_data['main_line'] = '无'
+    stock_em_zt_pool_df_data['sub_main_line'] = '无'
     # 上个交易交易日涨停股票
     last_trade_day_zt_df = zt_common_service_api.get_last_trade_day_zt(str_day)
 
@@ -78,8 +81,8 @@ def save_zt_info(str_day):
             try:
 
                 # 设置连板数目
-                stock_em_zt_pool_df_data = set_connected_boards_numbers(stock_em_zt_pool_df_data,
-                                                                        stock_one.symbol, last_trade_day_zt_df)
+                stock_em_zt_pool_df_data = set_connected_boards_numbers(stock_em_zt_pool_df_data.copy(),
+                                                                        stock_one.symbol, last_trade_day_zt_df.copy())
 
                 ths_zt_pool_one_df = ths_zt_pool_df_data.loc[ths_zt_pool_df_data['symbol'] == stock_one.symbol]
                 if data_frame_util.is_empty(ths_zt_pool_one_df):
@@ -96,6 +99,9 @@ def save_zt_info(str_day):
 
                 zt_analysis = ths_company_info_api.get_company_hot_info(stock_one.symbol,
                                                                         cookie_info_service.get_ths_cookie())
+                if zt_analysis == '':
+                    zt_analysis = ths_stock_zt_pool_api.zt_analyse(stock_one.symbol)
+
                 stock_em_zt_pool_df_data.loc[
                     stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'zt_analysis'] = zt_analysis
 
@@ -129,8 +135,6 @@ def save_zt_info(str_day):
 
     stock_em_zt_pool_df_data['str_day'] = str_day
     stock_em_zt_pool_df_data['_id'] = stock_em_zt_pool_df_data['symbol'] + "_" + str_day
-    # 主线标记 复盘用
-    stock_em_zt_pool_df_data['main_line'] = '无'
 
     stock_em_zt_pool_df_data = stock_em_zt_pool_df_data[ZT_FIELD]
 
@@ -152,16 +156,24 @@ def save_zt_info(str_day):
 
 # 设置连板数目
 def set_connected_boards_numbers(stock_em_zt_pool_df_data, symbol, last_trade_day_zt_df):
-    connected_boards_df = last_trade_day_zt_df.loc[
+    connected_boards_df_copy = last_trade_day_zt_df.loc[
         last_trade_day_zt_df['symbol'].isin(stock_em_zt_pool_df_data['symbol'])]
-
+    connected_boards_df = connected_boards_df_copy.copy()
     connected_boards_df['connected_boards_numbers'] = connected_boards_df['connected_boards_numbers'] + 1
 
     connected_boards_df_one = connected_boards_df.loc[connected_boards_df['symbol'] == symbol]
     if data_frame_util.is_not_empty(connected_boards_df_one):
-        connected_boards_df_one.loc[connected_boards_df_one['symbol'] == symbol, 'connected_boards_numbers'] = \
+        stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == symbol, 'connected_boards_numbers'] = \
             list(connected_boards_df_one['connected_boards_numbers'])[0]
 
+        if 'main_line' in connected_boards_df_one.columns:
+            stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == symbol, 'main_line'] = \
+                list(connected_boards_df_one['main_line'])[0]
+
+        if 'sub_main_line' in connected_boards_df_one.columns:
+            stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == symbol, 'sub_main_line'] = \
+                list(connected_boards_df_one['sub_main_line'])[0]
+
     return stock_em_zt_pool_df_data
 
 
@@ -169,16 +181,30 @@ def sync_miss_zt_data(stock_em_zt_pool_df_data, str_day):
     now_date = datetime.now()
     now_day = now_date.strftime('%Y-%m-%d')
     if now_day == str_day:
-        real_time_quotes_all_stocks_df = east_money_stock_api.get_real_time_quotes_all_stocks()
+        real_time_quotes_all_stocks_df = em_real_time_quotes_api.get_real_time_quotes_now(None, None)
         real_time_quotes_all_stocks_df = real_time_quotes_all_stocks_df.loc[
             (real_time_quotes_all_stocks_df['wei_bi'] == 100) & (real_time_quotes_all_stocks_df['chg'] >= 9)]
-        miss_zt_data_df = real_time_quotes_all_stocks_df.loc[~(
+        miss_zt_data_df_copy = real_time_quotes_all_stocks_df.loc[~(
             real_time_quotes_all_stocks_df['symbol'].isin(stock_em_zt_pool_df_data['symbol']))]
+        miss_zt_data_df = miss_zt_data_df_copy.copy()
         if data_frame_util.is_not_empty(miss_zt_data_df):
             miss_zt_data_df['buy_1_num'] = miss_zt_data_df['buy_1_num'].astype(float)
             miss_zt_data_df['now_price'] = miss_zt_data_df['now_price'].astype(float)
             miss_zt_data_df['closure_funds'] = round(miss_zt_data_df['buy_1_num'] * 100 * miss_zt_data_df['now_price'],
                                                      2)
+
+            company_info_industry_df = company_common_service_api.get_company_info_name()
+            company_info_industry_df = company_info_industry_df.loc[
+                company_info_industry_df['_id'].isin(miss_zt_data_df['symbol'])]
+
+            company_info_industry_df = company_info_industry_df[['_id', 'industry', 'name']]
+
+            company_info_industry_df = company_info_industry_df.set_index(['_id'], drop=True)
+            miss_zt_data_df = miss_zt_data_df.set_index(['symbol'], drop=False)
+
+            miss_zt_data_df = pd.merge(miss_zt_data_df, company_info_industry_df, how='outer',
+                                       left_index=True, right_index=True)
+
             miss_zt_data_df = miss_zt_data_df[[
                 'symbol',
                 'name',
@@ -206,7 +232,7 @@ def sync_miss_zt_data(stock_em_zt_pool_df_data, str_day):
 
 
 if __name__ == '__main__':
-    save_zt_info('2024-12-20')
+    save_zt_info('2025-11-04')
 # from datetime import datetime
 #
 # if __name__ == '__main__':
