@@ -5,6 +5,11 @@ file_path = os.path.abspath(__file__)
 end = file_path.index('mns') + 17
 project_path = file_path[0:end]
 sys.path.append(project_path)
+import warnings
+
+# 忽略所有警告
+warnings.filterwarnings("ignore")
+import mns_scheduler.company_info.em_stock_info.sync_em_stock_info_sync as sync_em_stock_info_sync
 import mns_scheduler.self_choose.ths_self_choose_service as ths_self_choose_service
 import mns_scheduler.risk.major_violations.register_and_investigate_stock_sync_api \
     as register_and_investigate_stock_sync_api
@@ -15,18 +20,17 @@ import mns_scheduler.dt.stock_dt_pool_sync as stock_dt_pool_sync_api
 import mns_scheduler.zb.stock_zb_pool_sync as stock_zb_pool_sync_api
 import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
 import mns_common.utils.date_handle_util as date_handle_util
-import mns_scheduler.k_line.sync.daily_week_month_line_sync as daily_week_month_line_sync_api
+import mns_scheduler.k_line.month_week_daily.daily_week_month_line_sync as daily_week_month_line_sync_api
 import mns_scheduler.company_info.announce.company_announce_sync_service as company_announce_sync_service
 import mns_scheduler.db.col_move_service as col_move_service
 import mns_scheduler.db.db_status as db_status_api
-import mns_scheduler.big_deal.ths_big_deal_sync as ths_big_deal_sync_api
 import mns_scheduler.zt.open_data.kcx_high_chg_open_data_sync as kcx_high_chg_open_data_sync
 import mns_scheduler.zt.export.export_kcx_high_chg_open_data_to_excel as export_kcx_high_chg_open_data_to_excel
 import mns_scheduler.zt.connected_boards.zt_five_boards_sync_api as zt_five_boards_sync_api
 import mns_scheduler.zt.zt_pool.em_zt_pool_sync_api as em_zt_pool_sync_api
 import mns_scheduler.k_line.clean.k_line_info_clean_task as k_line_info_clean_service
 import mns_scheduler.concept.clean.ths_concept_clean_api as ths_concept_choose_api
-import mns_common.api.em.east_money_stock_gdfx_free_top_10_api as east_money_stock_gdfx_free_top_10_api
+import mns_common.api.em.gd.east_money_stock_gdfx_free_top_10_api as east_money_stock_gdfx_free_top_10_api
 import \
     mns_scheduler.concept.ths.update_concept_info.sync_one_concept_all_symbols_api as sync_one_concept_all_symbols_api
 import \
@@ -49,14 +53,15 @@ import mns_scheduler.company_info.clean.company_info_clean_api as company_info_c
 import mns_scheduler.zt.zt_pool.ths_zt_pool_sync_api as ths_zt_pool_sync_api
 import mns_scheduler.trade.task.trader_task_service as trader_task_service
 import mns_scheduler.company_info.remark.company_remark_info_sync as company_remark_info_sync
-import mns_scheduler.finance.sync_financial_report_service_api as sync_financial_report_service_api
+import mns_scheduler.finance.sync_financial_report_service_task as sync_financial_report_service_task
 import mns_scheduler.hk.hk_industry_info_sync_service_api as hk_industry_info_sync_service_api
 import mns_scheduler.hk.hk_company_info_sync_service_api as hk_company_info_sync_service_api
 import mns_scheduler.zt.zt_pool.update_null_zt_reason_api as update_null_zt_reason_api
 import mns_scheduler.trade.tfp.stock_tfp_info_sync as stock_tfp_info_sync
 import mns_scheduler.industry.ths.ths_industry_sync_service as ths_industry_sync_service
-import mns_scheduler.db.task_handle_service as task_handle_service
-import mns_scheduler.extraIncome.one_minute.one_minute_sync_task as one_minute_sync_task
+import mns_scheduler.k_line.year_quarter.year_quarter_line_sync as year_quarter_line_sync
+import mns_scheduler.k_line.sync_status.k_line_sync_status_check as k_line_sync_status_check
+import mns_scheduler.company_info.base.sync_company_product_area_industry as sync_company_product_area_industry_api
 
 
 # 同步交易日期任务完成
@@ -91,7 +96,7 @@ def stock_sync_qfq_weekly():
     str_now_date = now_date.strftime('%Y-%m-%d')
     if date_handle_util.last_day_of_week(now_date):
         logger.info('同步每周行情数据(前复权):' + str_now_date)
-        daily_week_month_line_sync_api.sync_all_daily_data('weekly', 'qfq', 'stock_qfq_weekly', None)
+        daily_week_month_line_sync_api.sync_all_daily_data('weekly', 'qfq', 'stock_qfq_weekly', str_now_date)
 
 
 # # 定时同步每周交易行情数据(前复权)
@@ -101,7 +106,7 @@ def stock_sync_qfq_monthly():
     if date_handle_util.last_day_month(now_date):
         logger.info('同步每周行情数据(前复权):' + str_now_date)
         daily_week_month_line_sync_api.sync_all_daily_data('monthly', 'qfq', 'stock_qfq_monthly',
-                                                           None)
+                                                           str_now_date)
 
 
 #  当天实时数据备份
@@ -118,13 +123,13 @@ def db_status_check():
     db_status_api.db_status_check()
 
 
-# 同步大单数据
-def sync_ths_big_deal():
-    now_date = datetime.now()
-    str_now_day = now_date.strftime('%Y-%m-%d')
-    if trade_date_common_service_api.is_trade_day(str_now_day):
-        logger.info('更新大单数据')
-        ths_big_deal_sync_api.sync_ths_big_deal(False)
+# # 同步大单数据
+# def sync_ths_big_deal():
+#     now_date = datetime.now()
+#     str_now_day = now_date.strftime('%Y-%m-%d')
+#     if trade_date_common_service_api.is_trade_day(str_now_day):
+#         logger.info('更新大单数据')
+#         ths_big_deal_sync_api.sync_ths_big_deal(False)
 
 
 # 定时同步每日交易行情数据(前复权)
@@ -133,7 +138,7 @@ def stock_daily_sync_qfq():
     str_now_date = now_date.strftime('%Y-%m-%d')
     logger.info('同步每日行情数据(前复权):' + str_now_date)
     daily_week_month_line_sync_api.sync_all_daily_data('daily',
-                                                       'qfq', 'stock_qfq_daily', None)
+                                                       'qfq', 'stock_qfq_daily', str_now_date)
 
 
 # 同步当日k c x 高涨幅数据
@@ -179,7 +184,11 @@ def generate_new_day_k_line_info():
     now_date = datetime.now()
     str_day = now_date.strftime('%Y-%m-%d')
     # 生成下一个交易日日期k线数据 number=2 获取下一个交易日 日期
-    next_trade_day = trade_date_common_service_api.get_further_trade_date(str_day, 2)
+    if trade_date_common_service_api.is_trade_day(str_day):
+        dis_number = 2
+    else:
+        dis_number = 1
+    next_trade_day = trade_date_common_service_api.get_further_trade_date(str_day, dis_number)
     k_line_info_clean_service.sync_k_line_info_task(next_trade_day)
     logger.info('计算当日k线信息完成:{}', str_day)
 
@@ -341,23 +350,23 @@ def sync_high_risk_stocks():
 def sync_all_interactive_questions():
     now_date = datetime.now()
     str_day = now_date.strftime('%Y-%m-%d')
-    hour = now_date.hour
-    tag = (bool(1 - trade_date_common_service_api.is_trade_day(str_day))) or (hour >= 17)
+    # 非交易日同步
+    tag = bool(1 - trade_date_common_service_api.is_trade_day(str_day))
     if tag:
         logger.info('同步互动回答')
-        stock_irm_cninfo_service.sync_all_interactive_questions(None)
+        stock_irm_cninfo_service.sync_symbols_interactive_questions([])
 
 
-# 重开定时任务同步
-def real_time_sync_task_open():
-    logger.info("开启实时行情同步任务")
-    task_handle_service.real_time_sync_task_open()
+# # 重开定时任务同步
+# def real_time_sync_task_open():
+#     logger.info("开启实时行情同步任务")
+#     real_time_data_sync_check.real_time_sync_task_open()
 
-
-# 关闭实时行情任务
-def real_time_sync_task_close():
-    logger.info("关闭实时行情同步任务")
-    task_handle_service.real_time_sync_task_close()
+#
+# # 关闭实时行情任务
+# def real_time_sync_task_close():
+#     logger.info("关闭实时行情同步任务")
+#     real_time_data_sync_check.real_time_sync_task_close()
 
 
 # 打开交易客户端
@@ -380,7 +389,7 @@ def self_choose_stock_task():
 # 同步财务报表
 def sync_financial_report_task():
     logger.info('同步财务报表任务')
-    sync_financial_report_service_api.sync_financial_report()
+    sync_financial_report_service_task.sync_financial_report()
 
 
 # 同步hk公司信息
@@ -402,7 +411,7 @@ def update_null_zt_reason():
 
 # 同步公告信息
 def sync_company_announce():
-    company_announce_sync_service.sync_company_announce()
+    company_announce_sync_service.sync_company_announce(None)
 
 
 # 同步停复牌信息
@@ -412,6 +421,7 @@ def sync_stock_tfp():
     stock_tfp_info_sync.sync_stock_tfp(str_day)
 
 
+# 同步同花顺行业信息
 def sync_ths_industry_info():
     logger.info("同步同花顺行业信息开始")
     ths_industry_sync_service.sync_ths_industry_index()
@@ -419,161 +429,151 @@ def sync_ths_industry_info():
     logger.info("同步同花顺行业信息完成")
 
 
-def sync_one_minute_data():
-    logger.info("同步1分钟交易数据")
-    one_minute_sync_task.sync_one_minute_data()
+# 同步年线数据
+def sync_year_k_line():
+    logger.info("同步年线数据")
+    year_quarter_line_sync.sync_year_k_line()
+
+
+# 同步东方财富股票信息
+def sync_all_em_stock_info():
+    sync_em_stock_info_sync.sync_all_em_stock_info()
+
+
+# check 前复权k线和下一个交易日策略k线数据同步状态
+def check_k_line_sync_count():
+    logger.info("check前复权k线和下一个交易日策略k线数据同步状态")
+    k_line_sync_status_check.check_k_line_sync_count()
+
+
+# 同步公司产品区域信息
+def sync_company_product_area_industry():
+    sync_company_product_area_industry_api.sync_company_product_area_industry_task(None)
 
 
 # # 定义BlockingScheduler
 blockingScheduler = BlockingScheduler()
-# sync_trade_date 同步交易日期
-blockingScheduler.add_job(sync_trade_date, 'cron', hour='20', minute='43')
 
-# 跌停信息同步
-blockingScheduler.add_job(sync_stock_dt_pool, 'cron', hour='15,21', minute='37')
-
-# 炸板信息同步
-blockingScheduler.add_job(sync_stock_zb_pool, 'cron', hour='15,17,21', minute='15')
-
-# (前复权--周k线)
-blockingScheduler.add_job(stock_sync_qfq_weekly, 'cron', day_of_week='fri', hour=16, minute=20)
-
-# (前复权--月k线)
-blockingScheduler.add_job(stock_sync_qfq_monthly, 'cron', hour='15,18', minute='35')
-
-# 数据备份
-blockingScheduler.add_job(col_data_move, 'cron', hour='15', minute='26')
-
-# 数据库健康检查
-blockingScheduler.add_job(db_status_check, 'interval', seconds=30, max_instances=4)
-
-# 同步停复牌信息
-
-
-# 同步大单数据 暂停同步 20240430
-# blockingScheduler.add_job(sync_ths_big_deal, 'cron', hour='09', minute='30', max_instances=4)
-
-# todo 需要前后顺序执行
-# todo 当日k线信息
-# 同步一天k线 涨停 数据
-blockingScheduler.add_job(sync_daily_data_info, 'cron', hour='15,20', minute='26')
+#  同步东方财富a,etf,kzz,us,hk信息
+blockingScheduler.add_job(sync_all_em_stock_info, 'cron', hour='07', minute='31')
+blockingScheduler.add_job(sync_all_em_stock_info, 'cron', hour='15', minute='20')
 
 # 开盘前同步当天交易需要的k线数据
-blockingScheduler.add_job(sync_today_trade_k_line_info, 'cron', hour='07', minute='40')
+blockingScheduler.add_job(sync_today_trade_k_line_info, 'cron', hour='07', minute='50')
+
+# 同步单只股票下所有概念 by 股票代码
+blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='07,08,18', minute='45')
+
+# 打开交易客户端
+blockingScheduler.add_job(trader_client_auto_login, 'cron', hour='08,09', minute='04')
+
+# 获取当前持仓
+blockingScheduler.add_job(sync_position, 'cron', hour='0,08,09', minute='14')
+
+# 同步公司基本信息
+blockingScheduler.add_job(update_company_base_info, 'cron', hour='08,18', minute='05')
+
+# 同步互动回答
+blockingScheduler.add_job(sync_all_interactive_questions, 'cron', hour='06,17', minute='30')
 
 # 同步十大流通股东信息
-blockingScheduler.add_job(sync_stock_gdfx_free_top_10_one_day, 'cron', hour='08,22', minute='23')
+blockingScheduler.add_job(sync_stock_gdfx_free_top_10_one_day, 'cron', hour='06,18', minute='05')
 
-# 更新同花顺概念信息
-blockingScheduler.add_job(concept_info_clean, 'cron', hour='9,12,20', minute='24')
+# 同步港股公司和行业信息
+blockingScheduler.add_job(sync_hk_company_industry_info, 'cron', hour='08,15', minute='10')
 
 # 更新概念指数下所有股票组成 by 概念代码
 blockingScheduler.add_job(update_concept_all_detail_info, 'cron', hour='08,18,12', minute='30')
 
-# 同步单只股票下所有概念 by 股票代码
-blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='08,09,18', minute='00')
-# 同步单只股票下所有概念 by 股票代码 中午任务执行
-blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='12', minute='15,40')
+# 自选股操作
+blockingScheduler.add_job(self_choose_stock_task, 'cron', hour='08,17,21', minute='35')
 
 # 开盘前同步同花顺新概念指数
 blockingScheduler.add_job(sync_new_concept_index, 'cron', hour='09,22', minute='01,10,20,28,41,58')
 
+# 更新同花顺概念信息
+blockingScheduler.add_job(concept_info_clean, 'cron', hour='9,12,20', minute='24')
+
+# 更新开盘啦指数关系
+blockingScheduler.add_job(update_best_choose_plate_relation, 'cron', hour='09,18', minute='25')
+
+# 自动打新 打新中签高时间段 10:30-11:30
+blockingScheduler.add_job(auto_ipo_buy, 'cron', hour='09', minute='40,50')
+
+# 同步单只股票下所有概念 by 股票代码 中午任务执行
+blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='12', minute='15,40')
+
+# 数据备份
+blockingScheduler.add_job(col_data_move, 'cron', hour='15', minute='06')
+
+# 更新当天涨停股票池
+blockingScheduler.add_job(sync_stock_zt_pool, 'cron', hour='15,19', minute='10')
+
+# todo 需要前后顺序执行
+# todo 当日k线信息
+# 同步一天k线 涨停 数据
+blockingScheduler.add_job(sync_daily_data_info, 'cron', hour='15,20', minute='15')
+
+# (前复权--月k线)
+blockingScheduler.add_job(stock_sync_qfq_monthly, 'cron', hour='15,18', minute='35')
+
+# 复盘需要的数据
+blockingScheduler.add_job(sync_toady_stock_zt_pool, 'cron', hour='15', minute='40')
+
+# 炸板信息同步 同步停复牌信息
+blockingScheduler.add_job(sync_stock_zb_pool, 'cron', hour='16,21', minute='15')
+
+# 跌停信息同步
+blockingScheduler.add_job(sync_stock_dt_pool, 'cron', hour='16,21', minute='37')
+
+# 更新空的涨停原因股票
+blockingScheduler.add_job(update_null_zt_reason, 'cron', hour='16,17,18,19,20,21,22,23', minute='19')
+
+# 同步财务报表任务
+blockingScheduler.add_job(sync_financial_report_task, 'cron', hour='17', minute='30')
+
+# 同步同花顺行业信息
+blockingScheduler.add_job(sync_ths_industry_info, 'cron', hour='17,22', minute='38')
+
+# 更新开盘啦指数历史指数
+blockingScheduler.add_job(sync_kpl_best_his_quotes, 'cron', hour='18,22', minute='25')
+
+# 同步年线数据
+blockingScheduler.add_job(sync_year_k_line, 'cron', hour='18,23', minute='55')
+
+#  同步交易日期
+blockingScheduler.add_job(sync_trade_date, 'cron', hour='20', minute='43')
+
+# 同步公司备注信息
+blockingScheduler.add_job(sync_company_remark_info, 'cron', hour='22', minute='30')
+
+# 同步高风险股票
+blockingScheduler.add_job(sync_high_risk_stocks, 'cron', hour='0,12,16', minute='20')
+
+# (前复权--周k线)
+blockingScheduler.add_job(stock_sync_qfq_weekly, 'cron', day_of_week='fri', hour=16, minute=20)
+
+# 数据库健康检查
+blockingScheduler.add_job(db_status_check, 'interval', seconds=30, max_instances=4)
+
 # 同步同花顺新增概念指数(定时轮训,暂时10分钟)
 blockingScheduler.add_job(sync_new_concept_index_task, 'interval', minutes=10, max_instances=4)
 
 # 同步开盘啦新增精选概念(定时轮训,暂时五分钟)
 blockingScheduler.add_job(sync_all_kpl_plate_info, 'interval', minutes=5, max_instances=4)
 
-# 同步公司基本信息
-blockingScheduler.add_job(update_company_base_info, 'cron', hour='08,18', minute='05')
-# 更新当天涨停股票池
-blockingScheduler.add_job(sync_stock_zt_pool, 'cron', hour='15,19', minute='05')
-
-# 自动打新 打新中签高时间段 10:30-11:30
-blockingScheduler.add_job(auto_ipo_buy, 'cron', hour='10', minute='40,50')
-
-# 更新开盘啦指数关系
-blockingScheduler.add_job(update_best_choose_plate_relation, 'cron', hour='09,18', minute='25')
-
-# 更新开盘啦指数历史指数
-blockingScheduler.add_job(sync_kpl_best_his_quotes, 'cron', hour='18,22', minute='25')
-
-# 获取同花顺持仓
-blockingScheduler.add_job(sync_position, 'cron', hour='0,09', minute='10')
-
-# 同步高风险股票
-blockingScheduler.add_job(sync_high_risk_stocks, 'cron', hour='0,09,12,16', minute='20')
-
-# 同步互动回答
-blockingScheduler.add_job(sync_all_interactive_questions, 'cron', hour='08,12,17', minute='05')
-#
-# # 添加第一个时间段的任务：9:25 到 11:30，每 10 秒执行一次
-# blockingScheduler.add_job(
-#     real_time_task_check_status,
-#     'cron',
-#     hour='9-11',  # 9 点到 11 点
-#     minute='25-59',  # 25 分到 59 分（9:25-9:59）
-#     second='*/30',  # 每 20 秒
-#     max_instances=4
-# )
-#
-# # 添加第二个时间段的任务：10:00 到 11:30，每 10 秒执行一次
-# blockingScheduler.add_job(
-#     real_time_task_check_status,
-#     'cron',
-#     hour='10-11',  # 10 点到 11 点
-#     minute='*',  # 每分钟
-#     second='*/30',  # 每 20 秒
-#     max_instances=4
-# )
-#
-# # 添加第三个时间段的任务：13:00 到 15:00，每 10 秒执行一次
-# blockingScheduler.add_job(
-#     real_time_task_check_status,
-#     'cron',
-#     hour='13-15',  # 13 点到 15 点
-#     minute='*',  # 每分钟
-#     second='*/30',  # 每 20 秒
-#     max_instances=4
-# )
-
-# 重开定时任务同步
-
-blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='25')
-blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='29')
-blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='12', minute='59')
-# 关闭实时行情任务
-
-blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='09', minute='27')
-blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='11', minute='31')
-blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='15', minute='01')
-
-# 打开交易客户端
-blockingScheduler.add_job(trader_client_auto_login, 'cron', hour='08,12', minute='30')
-# 同步公司备注信息
-blockingScheduler.add_job(sync_company_remark_info, 'cron', hour='22', minute='30')
-# 自选股操作
-blockingScheduler.add_job(self_choose_stock_task, 'cron', hour='08,17,21', minute='30')
-# 同步财务报表任务
-blockingScheduler.add_job(sync_financial_report_task, 'cron', hour='17', minute='30')
-
-# 同步港股公司和行业信息
-blockingScheduler.add_job(sync_hk_company_industry_info, 'cron', hour='08,15', minute='10')
-# 更新空的涨停原因股票
-blockingScheduler.add_job(update_null_zt_reason, 'cron', hour='16,17,18,19,20,21,22,23', minute='19')
-
-# 同步同花顺行业信息
-blockingScheduler.add_job(sync_ths_industry_info, 'cron', hour='17,22', minute='38')
-
-# 同步一分钟交易数据
-blockingScheduler.add_job(sync_one_minute_data, 'cron', hour='17,22', minute='55')
-
 # 同步新公告信息 感觉没有必要同步 直接连接过去查看
 # blockingScheduler.add_job(sync_company_announce, 'cron', hour='07,18,23', minute='33')
 
+#  check 前复权k线和下一个交易日策略k线数据同步状态
+blockingScheduler.add_job(check_k_line_sync_count, 'cron', hour='0,23', minute='10')
+
+# 同步公司产品区域信息
+blockingScheduler.add_job(sync_company_product_area_industry, 'cron', day_of_week='sat,sun', hour='10,20',
+                          minute='10')
+
 print('定时任务启动成功')
 blockingScheduler.start()
 #
 # if __name__ == '__main__':
-#
-#     sync_daily_data_info()
+#     sync_company_product_area_industry()
